xclim package
=============

Subpackages
-----------

.. toctree::

   xclim.atmos
   xclim.indices
   xclim.land
   xclim.seaIce

Submodules
----------

xclim.checks module
-------------------

.. automodule:: xclim.checks
   :members:
   :undoc-members:
   :show-inheritance:

xclim.ensembles module
----------------------

.. automodule:: xclim.ensembles
   :members:
   :undoc-members:
   :show-inheritance:

xclim.generic module
--------------------

.. automodule:: xclim.generic
   :members:
   :undoc-members:
   :show-inheritance:

xclim.run\_length module
------------------------

.. automodule:: xclim.run_length
   :members:
   :undoc-members:
   :show-inheritance:

xclim.stats module
------------------

.. automodule:: xclim.stats
   :members:
   :undoc-members:
   :show-inheritance:

xclim.streamflow module
-----------------------

.. automodule:: xclim.streamflow
   :members:
   :undoc-members:
   :show-inheritance:

xclim.subset module
-------------------

.. automodule:: xclim.subset
   :members:
   :undoc-members:
   :show-inheritance:

xclim.utils module
------------------

.. automodule:: xclim.utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: xclim
   :members:
   :undoc-members:
   :show-inheritance:
